Exec — Poezio 0.9-dev documentation

# Exec

This plugin lets you execute a system command through poezio.

## Usage

Warning

Running commands that start a daemon or an interface is not a good idea.

/exec

  Usage: `/exec [-o|-O] <command>`

  Execute a system command.

      /exec command

  Will give you the result in the information buffer.

      /exec -o command

  Will send the result of the command into the current tab, if possible.

      /exec -O command

  Will send the result of the command and the command summary into the current tab, if possible.